@@ -8,7 +8,7 @@ import sass
 
 from .launch import update_thebelab_context, init_thebelab_core, add_hub_urls
 
-__version__ = "0.0.15"
+__version__ = "0.0.16"
 SPHINX_LOGGER = logging.getLogger(__name__)
 
 
@@ -52,13 +52,15 @@ def add_to_context(app, pagename, templatename, context, doctree):
         include_item_names=False,
         with_home_page=False,
         number_sections=False,
+        prev_section_numbers=None,
     ):
         # In case users give a string configuration
         if isinstance(number_sections, str):
             number_sections = number_sections.lower() == "true"
         if isinstance(with_home_page, str):
             with_home_page = with_home_page.lower() == "true"
-
+        if prev_section_numbers is None:
+            prev_section_numbers = []
         if len(nav) == 0:
             return ""
 
@@ -116,12 +118,21 @@ def add_to_context(app, pagename, templatename, context, doctree):
             # Now begin rendering the links
             active = "active" if child["active"] else ""
             ul.append("  " + f'<li class="{active}">')
+
             # Render links for the top-level names if we wish
             if include_item_names:
                 item_title = child["title"]
                 if number_sections and not child["url"].startswith("http"):
-                    item_title = f"{ii_num}. {item_title}"
+                    this_section_numbers = prev_section_numbers + [ii_num]
+                    number_title = ".".join(str(ii) for ii in this_section_numbers)
+                    # Handle the case of top-level section numbers
+                    if "." not in number_title:
+                        number_title += "."
+                    item_title = f"{number_title} {item_title}"
                     ii_num += 1
+                else:
+                    this_section_numbers = None
+
                 if child["url"].startswith("http"):
                     # Add an external icon for external navbar links
                     item_title += '<i class="fas fa-external-link-alt"></i>'
@@ -143,6 +154,7 @@ def add_to_context(app, pagename, templatename, context, doctree):
                     level=next_level,
                     include_item_names=True,
                     number_sections=number_sections,
+                    prev_section_numbers=this_section_numbers,
                 )
                 ul.append(child_list)
             ul.append("  " + "</li>")
